from launch import LaunchDescription
from launch_ros.actions import Node
import os
from ament_index_python.packages import get_package_share_directory
import xacro

def generate_launch_description():

    # Define the path to the Xacro file
    ur_robotiq_desc_pkg_path = get_package_share_directory('ur_robotiq_description')
    xacro_file_path = os.path.join(ur_robotiq_desc_pkg_path, 'urdf', 'ur_robotiq.urdf.xacro')

    # Process the Xacro file to generate URDF
    doc = xacro.process_file(xacro_file_path)
    robot_description = {'robot_description': doc.toxml()}

    # Node to publish robot state to TF
    robot_state_publisher_node = Node(
        package='robot_state_publisher',
        executable='robot_state_publisher',
        output='both',
        parameters=[robot_description],
    )

    # Node to launch RViz
    rviz_node = Node(
        package='rviz2',
        executable='rviz2',
        name='rviz2',
        arguments=['-d', os.path.join(ur_robotiq_desc_pkg_path, 'rviz', 'ur3e_robotiq.rviz')],
        output='screen'
    )

    # Define and return LaunchDescription
    return LaunchDescription([
        robot_state_publisher_node,
        rviz_node,
        # Add other necessary nodes and configurations here
    ])

